locals {
  netconn_target_config = jsondecode(var.extra_environment.JOB_CONFIG_NETCONN_TARGET)
  nta_pop_filter_config = jsondecode(var.extra_environment.JOB_CONFIG_AGGREGATION)
  nta_pop_lib_version   = lookup(local.netconn_target_config, "lib_version", var.default_nta_pop_lib_version)
  # This is a workaround for not having this variable in the team cluster.
  # Metrics will fail in the team cluster, but the job will succeed.
  wavefront_url = "https://sbu.wavefront.com"

  src_account_id = {
    exists = {
      "--src_account_id" = lookup(var.extra_environment, "SRC_ACCOUNT_ID", "")
    }
    not_exists = {}
  }
}

data "aws_iam_role" "job_role" {
  name = var.iam_role_name
}

resource "aws_glue_job" "nta_pop_filter_daily_job" {
  name                   = "${var.name_prefix}-netconn_target"
  tags                   = var.tags
  glue_version           = "3.0"
  role_arn               = data.aws_iam_role.job_role.arn
  max_retries            = 0
  timeout                = local.netconn_target_config.timeout
  number_of_workers      = local.netconn_target_config.num_workers
  worker_type            = local.netconn_target_config.worker_type
  security_configuration = aws_glue_security_configuration.nta_pop_filter.name

  default_arguments = merge(
    # This indicates that this is a x-account job
    local.src_account_id[lookup(var.extra_environment, "SRC_ACCOUNT_ID", "") != "" ? "exists" : "not_exists"],
    {
      "--dst_table_name"                   = "${var.database_name}.${local.netconn_target_config.dest_table_name}"
      "--src_table_name"                   = var.extra_environment.SRC_TABLE_NAME
      "--TempDir"                          = "s3://${var.processing_bucket_name}/tmp/"
      "--extra-py-files"                   = "s3://${var.processing_bucket_name}/lib/nta_pop_filter-${local.nta_pop_lib_version}-py3-none-any.whl"
      "--enable-continuous-cloudwatch-log" = "true"
      "--enable-glue-datacatalog"          = ""
      "--enable-metrics"                   = ""
      "--additional-python-modules"        = "wavefront-sdk-python"
      "--enable-spark-ui"                  = "true"
      "--spark-event-logs-path"            = "s3://${var.processing_bucket_name}/logs/nta_pop_filter_daily/"
      "--env"                              = var.extra_environment.ENV_NAME
      "--wavefront_url"                    = local.wavefront_url
      "--mcs2_env"                         = var.mcs2_env
    }
  )

  command {
    script_location = "s3://${var.processing_bucket_name}/jobs/netconn_target/glue_handler_netconn_target-${local.nta_pop_lib_version}.py"
  }

  execution_property {
    max_concurrent_runs = local.netconn_target_config["max_concurrency"]
  }
}

resource "aws_glue_job" "nta_pop_filter_31_days_job" {
  name                   = "${var.name_prefix}-nta-pop-filter-31days"
  tags                   = var.tags
  glue_version           = "3.0"
  role_arn               = data.aws_iam_role.job_role.arn
  max_retries            = 0
  timeout                = local.nta_pop_filter_config.timeout
  number_of_workers      = local.nta_pop_filter_config.num_workers
  worker_type            = local.nta_pop_filter_config.worker_type
  security_configuration = aws_glue_security_configuration.nta_pop_filter.name

  default_arguments = merge(
    # This indicates that this is a x-account job
    local.src_account_id[lookup(var.extra_environment, "SRC_ACCOUNT_ID", "") != "" ? "exists" : "not_exists"],
    {
      "--src_table_name"                       = "${var.database_name}.${local.netconn_target_config.dest_table_name}"
      "--bloom_filter_output_bucket"           = var.data_bucket_name
      "--bloom_filter_fpp"                     = local.nta_pop_filter_config.bloom_filter_fpp
      "--drop_percentage"                      = local.nta_pop_filter_config.drop_percentage
      "--pre_drop_threshold_remote_ip_address" = local.nta_pop_filter_config.pre_drop_threshold_remote_ip_address
      "--pre_drop_threshold_domain"            = local.nta_pop_filter_config.pre_drop_threshold_domain
      "--TempDir"                              = "s3://${var.processing_bucket_name}/tmp/"
      "--extra-py-files"                       = "s3://${var.processing_bucket_name}/lib/nta_pop_filter-${local.nta_pop_lib_version}-py3-none-any.whl"
      "--extra-jars"                           = "s3://${var.processing_bucket_name}/lib/bloom-filter-lib-${var.bloom_filter_lib_version}.jar"
      "--enable-continuous-cloudwatch-log"     = "true"
      "--enable-glue-datacatalog"              = ""
      "--enable-metrics"                       = ""
      "--additional-python-modules"            = "wavefront-sdk-python"
      "--enable-spark-ui"                      = "true"
      "--spark-event-logs-path"                = "s3://${var.processing_bucket_name}/logs/nta_pop_filter_31days/"
      "--env"                                  = var.extra_environment.ENV_NAME
      "--wavefront_url"                        = local.wavefront_url
      "--mcs2_env"                             = var.mcs2_env
    }
  )

  command {
    script_location = "s3://${var.processing_bucket_name}/jobs/aggregation/glue_handler-${local.nta_pop_lib_version}.py"
  }

  execution_property {
    max_concurrent_runs = local.nta_pop_filter_config["max_concurrency"]
  }
}
